/* Exemplet visar hur man kan flytta element inom en drop zone. Detta görs i koden
   för händelsen drop, där e.offsetX och e.offsetY används för att avgöra musens
   position och därmed var elementet släpptes. För att flytta elementet läggs det
   in nya värden i elementets left- och top-egenskaper.
   När man börjar dra elementet, pekar man kanske inte på det övre vänstra hörnet.
   För att kompensera för detta sparas avståndet mellan hörnet och muspekaren i
   variablerna dx och dy, då man börjar dra. Dessa värden dras sedan från offsetX
   och offsetY, då man släpper elementet.
   Observera att det är två olika event-objekt och därmed olika offsetX och offsetY
   vid dragstart och drop. Vid dragstart är offset-värdena inom det element som man
   drar, medan vid drop är offset-värdena inom dropzone-elementet. */
// --------------------------------------------------
// Globala variabler och konstanter
let coordElem;  // Element för utskrift av koordinater
// --------------------------------------------------
// Initiering då webbsidan är inläst
function init() {
    coordElem = document.querySelector("#coordinates");
    let dragElems = document.querySelectorAll("#dragItems div");
    let displacement = dragElems[0].offsetWidth + 10;
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].style.top = "10px";
        dragElems[i].style.left = (10 + displacement * i) + "px";
        dragElems[i].draggable = true;
        dragElems[i].addEventListener("dragstart", dragStart);
    }
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    let dragElem = this;
    let dropElem = document.querySelector("#dropZone");
    let dx = e.offsetX; // Avstånd från boxens vänsterkant ...
    let dy = e.offsetY; // ... och överkant till musens position
    // e.offsetX och e.offsetY är här inom dragElem, dvs boxen man drar
    dragElem.addEventListener("dragend", dragEnd);
    dropElem.addEventListener("dragover", dropZone);
    dropElem.addEventListener("drop", dropZone);
    //dragElem.style.opacity = 0;
    setTimeout(function() {dragElem.style.opacity = 0;}, 50); // Dölj originalet efter 50 ms
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        dragElem.removeEventListener("dragend", dragEnd);
        dropElem.removeEventListener("dragover", dropZone);
        dropElem.removeEventListener("drop", dropZone);
        dragElem.style.opacity = 1; // Visa originalet igen
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let x = e.offsetX - dx; // Kompensera med dx och dy ...
        let y = e.offsetY - dy; // för var i boxen man tryckte ner musen
        // e.offsetX och e.offsetY är här inom drop zone
        switch (e.type) {
            case "dragover": // Visa "koordinaterna"
                coordElem.innerHTML = "x = " + parseInt(x) + ", y = " + parseInt(y);
                break;
            case "drop": // Flytta boxen till positionen
                dragElem.style.left = x + "px";
                dragElem.style.top = y + "px";
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
